@@ -320,14 +320,10 @@ class Competitor(Base):
             pers.append(serializer.addPlayer(self.player3))
         if self.idplayer4:
             pers.append(serializer.addPlayer(self.player4))
-        if self.points:
-            simple['points'] = self.points
-        if self.netscore:
-            simple['netscore'] = self.netscore
-        if self.totscore:
-            simple['totscore'] = self.totscore
-        if self.bucholz:
-            simple['bucholz'] = self.bucholz
+        simple['points'] = self.points
+        simple['netscore'] = self.netscore
+        simple['totscore'] = self.totscore
+        simple['bucholz'] = self.bucholz
         if self.prize:
             simple['prize'] = str(self.prize)
         if self.retired:
