@@ -12,13 +12,14 @@ from sqlalchemy import (
     ForeignKey,
     Index,
     Sequence,
+    and_,
     func,
     or_,
     select,
     )
 from sqlalchemy.ext.declarative import declared_attr
 from sqlalchemy.ext.hybrid import hybrid_property
-from sqlalchemy.orm import backref, object_session, relationship
+from sqlalchemy.orm import aliased, backref, object_session, relationship
 from sqlalchemy.orm.exc import MultipleResultsFound, NoResultFound
 from sqlalchemy.sql import union_all
 
@@ -677,7 +678,7 @@ class Player(GloballyUnique, Base):
         return replaced
 
     def partecipations(self):
-        "Return the list of Competitors involving this player."
+        "Return the list of :py:class:`competitors <.Competitor>` involving this player."
 
         from . import Competitor
 
@@ -730,6 +731,77 @@ class Player(GloballyUnique, Base):
                 losts += 1
         return (wins, losts, ties)
 
+    def opponents(self):
+        "Return a summary of the opponents this player met."
+
+        from . import Competitor, Match
+
+        s = object_session(self)
+
+        ct1 = Competitor.__table__.alias()
+        ct2 = Competitor.__table__.alias()
+        cto1 = Competitor.__table__.alias()
+        cto2 = Competitor.__table__.alias()
+        mt1 = Match.__table__.alias()
+        mt2 = Match.__table__.alias()
+
+        qm = union_all(
+            select([cto1.c.idplayer1, mt1.c.score1, mt1.c.score2],
+                   and_(ct1.c.idplayer1 == self.idplayer,
+                        ct1.c.idplayer2 == None),
+                   from_obj=mt1
+                   .join(ct1, mt1.c.idcompetitor1==ct1.c.idcompetitor)
+                   .join(cto1, mt1.c.idcompetitor2==cto1.c.idcompetitor)),
+            select([cto2.c.idplayer1, mt2.c.score2, mt2.c.score1],
+                   and_(ct2.c.idplayer1 == self.idplayer,
+                        ct2.c.idplayer2 == None),
+                   from_obj=mt2
+                   .join(ct2, mt2.c.idcompetitor2==ct2.c.idcompetitor)
+                   .join(cto2, mt2.c.idcompetitor1==cto2.c.idcompetitor)))
+
+        summary = {}
+
+        for m in s.execute(qm):
+            opponent, ps, os = m
+            data = summary.setdefault(opponent, [0, 0, 0, 0, 0])
+            if ps > os:
+                data[0] += 1
+            elif ps < os:
+                data[1] += 1
+            else:
+                data[2] += 1
+            data[3] += ps
+            data[4] += os
+
+        result = [(s.query(Player).get(o), d[0], d[1], d[2], d[3], d[4])
+                  for o,d in summary.items()]
+
+        return sorted(result,
+                      key=lambda i: (-(i[1] + i[2] + i[3]), i[0].lastname, i[0].firstname))
+
+    def opponentMatches(self, opponent):
+        "Return the list of :py:class:`matches <.Match>` against the `opponent`."
+
+        from . import Competitor, Match
+
+        s = object_session(self)
+        c1 = aliased(Competitor)
+        c2 = aliased(Competitor)
+
+        matches = s.query(Match) \
+                   .join(c1, Match.idcompetitor1 == c1.idcompetitor) \
+                   .join(c2, Match.idcompetitor2 == c2.idcompetitor) \
+                   .filter(or_(and_(c1.idplayer1 == self.idplayer,
+                                    c1.idplayer2 == None,
+                                    c2.idplayer1 == opponent.idplayer,
+                                    c2.idplayer2 == None),
+                               and_(c1.idplayer1 == opponent.idplayer,
+                                    c1.idplayer2 == None,
+                                    c2.idplayer1 == self.idplayer,
+                                    c2.idplayer2 == None))).all()
+
+        return sorted(matches, key=lambda m: m.tourney.date)
+
     def serialize(self, serializer):
         """Reduce a single player to a simple dictionary.
 
