@@ -400,17 +400,20 @@ class TourneyPrintout(BasicPrintout):
     def getArgumentsFromRequest(klass, session, request):
         t = translator(request)
 
+        id = request.matchdict['id']
         try:
-            idtourney = int(request.matchdict['id'])
+            idtourney = int(id)
         except ValueError:
             try:
-                entity = session.query(Tourney).filter_by(guid=request.matchdict['id']).one()
+                entity = session.query(Tourney).filter_by(guid=id).one()
             except NoResultFound:
-                raise OperationAborted(t(_('Bad tourney guid')))
+                raise OperationAborted(t(_('Bad tourney id: $id',
+                                           mapping=dict(id=repr(id)))))
         else:
             entity = session.query(Tourney).get(idtourney)
             if entity is None:
-                raise OperationAborted(t(_('Bad tourney id')))
+                raise OperationAborted(t(_('Bad tourney id: $id',
+                                           mapping=dict(id=str(idtourney)))))
 
         return [entity]
 
@@ -1316,17 +1319,20 @@ class Badges(object):
     def getArgumentsFromRequest(klass, session, request):
         t = translator(request)
 
+        id = request.matchdict['id']
         try:
-            idtourney = int(request.matchdict['id'])
+            idtourney = int(id)
         except ValueError:
             try:
-                entity = session.query(Tourney).filter_by(guid=request.matchdict['id']).one()
+                entity = session.query(Tourney).filter_by(guid=id).one()
             except NoResultFound:
-                raise OperationAborted(t(_('Bad tourney guid')))
+                raise OperationAborted(t(_('Bad tourney id: $id',
+                                           mapping=dict(id=repr(id)))))
         else:
             entity = session.query(Tourney).get(idtourney)
             if entity is None:
-                raise OperationAborted(t(_('Bad tourney id')))
+                raise OperationAborted(t(_('Bad tourney id: $id',
+                                           mapping=dict(id=str(idtourney)))))
 
         return [entity]
 
@@ -1588,17 +1594,20 @@ class ChampionshipRanking(BasicPrintout):
     def getArgumentsFromRequest(klass, session, request):
         t = translator(request)
 
+        id = request.matchdict['id']
         try:
-            idchampionship = int(request.matchdict['id'])
+            idchampionship = int(id)
         except ValueError:
             try:
-                entity = session.query(Championship).filter_by(guid=request.matchdict['id']).one()
+                entity = session.query(Championship).filter_by(guid=id).one()
             except NoResultFound:
-                raise OperationAborted(t(_('Bad championship guid')))
+                raise OperationAborted(t(_('Bad championship id: $id',
+                                           mapping=dict(id=repr(id)))))
         else:
             entity = session.query(Championship).get(idchampionship)
             if entity is None:
-                raise OperationAborted(t(_('Bad championship id')))
+                raise OperationAborted(t(_('Bad championship id: $id',
+                                           mapping=dict(id=str(idchampionship)))))
 
         return [entity]
 
@@ -1806,17 +1815,20 @@ class RatingRanking(BasicPrintout):
     def getArgumentsFromRequest(klass, session, request):
         t = translator(request)
 
+        id = request.matchdict['id']
         try:
-            idrating = int(request.matchdict['id'])
+            idrating = int(id)
         except ValueError:
             try:
-                entity = session.query(Rating).filter_by(guid=request.matchdict['id']).one()
+                entity = session.query(Rating).filter_by(guid=id).one()
             except NoResultFound:
-                raise OperationAborted(t(_('Bad rating guid')))
+                raise OperationAborted(t(_('Bad rating id: $id',
+                                           mapping=dict(id=repr(id)))))
         else:
             entity = session.query(Rating).get(idrating)
             if entity is None:
-                raise OperationAborted(t(_('Bad rating id')))
+                raise OperationAborted(t(_('Bad rating id: $id',
+                                           mapping=dict(id=str(idrating)))))
 
         return [entity, getattr(request, '_LOCALE_', 'en')]
 
