@@ -207,16 +207,17 @@ def opponentChart(request):
     owins = 0
     odata = []
     for match in matches:
-        if match.competitor1.player1 is player:
-            if match.score1 > match.score2:
-                pwins += 1
+        if match.score1 != match.score2:
+            if match.competitor1.player1 is player:
+                if match.score1 > match.score2:
+                    pwins += 1
+                else:
+                    owins += 1
             else:
-                owins += 1
-        else:
-            if match.score1 < match.score2:
-                pwins += 1
-            else:
-                owins += 1
+                if match.score1 < match.score2:
+                    pwins += 1
+                else:
+                    owins += 1
         pdata.append(pwins)
         odata.append(owins)
 
